"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var createMeta_1 = __importDefault(require("../src/createMeta"));
var assert_1 = __importDefault(require("assert"));
var ciDict_json_1 = __importDefault(require("../src/ciDict.json"));
var messages_1 = require("@cucumber/messages");
describe('createMeta', function () {
    it('defines the implementation product', function () {
        var meta = createMeta_1.default('someTool', '1.2.3', {}, {});
        assert_1.default.strictEqual(meta.implementation.name, 'someTool');
        assert_1.default.strictEqual(meta.implementation.version, '1.2.3');
    });
    it('detects CircleCI', function () {
        var envDict = {
            CIRCLE_BUILD_URL: 'the-url',
            CIRCLE_REPOSITORY_URL: 'the-remote',
            CIRCLE_BRANCH: 'the-branch',
            CIRCLE_SHA1: 'the-revision',
            CIRCLE_TAG: 'the-tag',
        };
        var meta = createMeta_1.default('someTool', '1.2.3', envDict, ciDict_json_1.default);
        assert_1.default.deepStrictEqual(meta.ci, messages_1.messages.Meta.CI.create({
            name: 'CircleCI',
            url: 'the-url',
            git: {
                remote: 'the-remote',
                branch: 'the-branch',
                revision: 'the-revision',
                tag: 'the-tag',
            },
        }));
    });
    it('detects GitHub Actions', function () {
        var envDict = {
            GITHUB_SERVER_URL: 'https://github.com',
            GITHUB_REPOSITORY: 'cucumber/cucumber-ruby',
            GITHUB_RUN_ID: '140170388',
            GITHUB_SHA: 'the-revision',
            GITHUB_REF: 'refs/tags/the-tag',
        };
        var meta = createMeta_1.default('someTool', '1.2.3', envDict, ciDict_json_1.default);
        assert_1.default.deepStrictEqual(meta.ci, messages_1.messages.Meta.CI.create({
            name: 'GitHub Actions',
            url: 'https://github.com/cucumber/cucumber-ruby/actions/runs/140170388',
            git: {
                remote: 'https://github.com/cucumber/cucumber-ruby.git',
                branch: undefined,
                revision: 'the-revision',
                tag: 'the-tag',
            },
        }));
    });
    it('detects GitHub Actions with custom base url', function () {
        var envDict = {
            GITHUB_SERVER_URL: 'https://github.company.com',
            GITHUB_REPOSITORY: 'cucumber/cucumber-ruby',
            GITHUB_RUN_ID: '140170388',
            GITHUB_SHA: 'the-revision',
            GITHUB_REF: 'refs/heads/the-branch',
        };
        var meta = createMeta_1.default('someTool', '1.2.3', envDict, ciDict_json_1.default);
        assert_1.default.deepStrictEqual(meta.ci, messages_1.messages.Meta.CI.create({
            name: 'GitHub Actions',
            url: 'https://github.company.com/cucumber/cucumber-ruby/actions/runs/140170388',
            git: {
                remote: 'https://github.company.com/cucumber/cucumber-ruby.git',
                branch: 'the-branch',
                revision: 'the-revision',
                tag: undefined,
            },
        }));
    });
    it('post-processes git refs to branch', function () {
        var envDict = {
            BUILD_URI: 'the-url',
            BUILD_REPOSITORY_URI: 'the-remote',
            BUILD_SOURCEBRANCH: 'refs/heads/main',
            BUILD_SOURCEVERSION: 'the-revision',
        };
        var meta = createMeta_1.default('someTool', '1.2.3', envDict, ciDict_json_1.default);
        assert_1.default.deepStrictEqual(meta.ci, messages_1.messages.Meta.CI.create({
            name: 'Azure Pipelines',
            url: 'the-url',
            git: {
                remote: 'the-remote',
                branch: 'main',
                revision: 'the-revision',
                tag: undefined,
            },
        }));
    });
    it('post-processes git refs to tag', function () {
        var envDict = {
            BUILD_URI: 'the-url',
            BUILD_REPOSITORY_URI: 'the-remote',
            BUILD_SOURCEBRANCH: 'refs/tags/v1.2.3',
            BUILD_SOURCEVERSION: 'the-revision',
        };
        var meta = createMeta_1.default('someTool', '1.2.3', envDict, ciDict_json_1.default);
        assert_1.default.deepStrictEqual(meta.ci, messages_1.messages.Meta.CI.create({
            name: 'Azure Pipelines',
            url: 'the-url',
            git: {
                remote: 'the-remote',
                branch: undefined,
                revision: 'the-revision',
                tag: 'v1.2.3',
            },
        }));
    });
});
//# sourceMappingURL=createMetaTest.js.map