"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatSummary = void 0;
const lodash_1 = __importDefault(require("lodash"));
const duration_1 = __importDefault(require("duration"));
const status_1 = __importDefault(require("../../status"));
const time_1 = require("../../time");
const messages_1 = require("@cucumber/messages");
const STATUS_REPORT_ORDER = [
    status_1.default.FAILED,
    status_1.default.AMBIGUOUS,
    status_1.default.UNDEFINED,
    status_1.default.PENDING,
    status_1.default.SKIPPED,
    status_1.default.PASSED,
];
function formatSummary({ colorFns, testCaseAttempts, testRunDuration, }) {
    const testCaseResults = [];
    const testStepResults = [];
    let totalStepDuration = time_1.getZeroDuration();
    testCaseAttempts.forEach(({ testCase, worstTestStepResult, stepResults }) => {
        Object.values(stepResults).forEach((stepResult) => {
            totalStepDuration = time_1.addDurations(totalStepDuration, stepResult.duration);
        });
        if (!worstTestStepResult.willBeRetried) {
            testCaseResults.push(worstTestStepResult);
            lodash_1.default.each(testCase.testSteps, (testStep) => {
                if (testStep.pickleStepId !== '') {
                    testStepResults.push(stepResults[testStep.id]);
                }
            });
        }
    });
    const scenarioSummary = getCountSummary({
        colorFns,
        objects: testCaseResults,
        type: 'scenario',
    });
    const stepSummary = getCountSummary({
        colorFns,
        objects: testStepResults,
        type: 'step',
    });
    const durationSummary = `${getDurationSummary(testRunDuration)} (executing steps: ${getDurationSummary(totalStepDuration)})\n`;
    return [scenarioSummary, stepSummary, durationSummary].join('\n');
}
exports.formatSummary = formatSummary;
function getCountSummary({ colorFns, objects, type, }) {
    const counts = lodash_1.default.chain(objects).groupBy('status').mapValues('length').value();
    const total = lodash_1.default.chain(counts).values().sum().value();
    let text = `${total.toString()} ${type}${total === 1 ? '' : 's'}`;
    if (total > 0) {
        const details = [];
        STATUS_REPORT_ORDER.forEach((status) => {
            if (counts[status] > 0) {
                details.push(colorFns.forStatus(status)(`${counts[status].toString()} ${status_1.default[status].toLowerCase()}`));
            }
        });
        text += ` (${details.join(', ')})`;
    }
    return text;
}
function getDurationSummary(durationMsg) {
    const start = new Date(0);
    const end = new Date(messages_1.TimeConversion.durationToMilliseconds(durationMsg));
    const duration = new duration_1.default(start, end);
    // Use spaces in toString method for readability and to avoid %Ls which is a format
    return duration.toString('%Ms m %S . %L s').replace(/ /g, '');
}
//# sourceMappingURL=summary_helpers.js.map