/// <reference types="node" />
import { Writable } from 'stream';
declare type HttpMethod = 'GET' | 'HEAD' | 'POST' | 'PUT' | 'DELETE' | 'CONNECT' | 'OPTIONS' | 'TRACE' | 'PATCH';
/**
 * This Writable writes data to a HTTP/HTTPS URL.
 *
 * It has special handling for https://reports.cucumber.io/
 * which uses an API where the first request is a `GET`,
 * and if the response is 202 with a Location header, issues
 * a PUT request to that URL.
 *
 * 3xx redirects are not currently followed.
 */
export default class HttpStream extends Writable {
    private readonly url;
    private readonly method;
    private readonly headers;
    private readonly reportLocation;
    private tempFilePath;
    private tempFile;
    private responseBodyFromGet;
    constructor(url: string, method: HttpMethod, headers: {
        [name: string]: string;
    }, reportLocation: (content: string) => void);
    _write(chunk: any, encoding: BufferEncoding, callback: (err?: Error | null) => void): void;
    _final(callback: (error?: Error | null) => void): void;
    private sendRequest;
}
export {};
