"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var jsdom_1 = require("jsdom");
var react_dom_1 = __importDefault(require("react-dom"));
var react_1 = __importDefault(require("react"));
var Attachment_1 = __importDefault(require("../src/components/gherkin/Attachment"));
var messages_1 = require("@cucumber/messages");
var assert_1 = __importDefault(require("assert"));
describe('<Attachment>', function () {
    it('renders an image', function () {
        var dom = new jsdom_1.JSDOM('<!DOCTYPE html><html lang="en"><body><div id="content"></div></body></html>');
        // React complains if we don't do this
        // @ts-ignore
        global.window = dom.window;
        var document = dom.window.document;
        var binary = new Uint8Array(10);
        binary.fill(255, 0, binary.length);
        var attachment = messages_1.messages.Attachment.create({
            mediaType: 'image/png',
            body: 'fake-base64',
            contentEncoding: messages_1.messages.Attachment.ContentEncoding.BASE64,
        });
        var attachmentElement = react_1.default.createElement(Attachment_1.default, { attachment: attachment });
        react_dom_1.default.render(attachmentElement, document.getElementById('content'));
        var img = document.querySelector('#content img');
        assert_1.default.strictEqual(img.getAttribute('src'), 'data:image/png;base64,fake-base64');
    });
    it('renders base64 encoded plaintext', function () {
        var dom = new jsdom_1.JSDOM('<!DOCTYPE html><html lang="en"><body><div id="content"></div></body></html>');
        // React complains if we don't do this
        // @ts-ignore
        global.window = dom.window;
        var document = dom.window.document;
        var attachment = messages_1.messages.Attachment.create({
            mediaType: 'text/plain',
            body: Buffer.from('hello').toString('base64'),
            contentEncoding: messages_1.messages.Attachment.ContentEncoding.BASE64,
        });
        var attachmentElement = react_1.default.createElement(Attachment_1.default, { attachment: attachment });
        react_dom_1.default.render(attachmentElement, document.getElementById('content'));
        var pre = document.querySelector('#content pre');
        assert_1.default.strictEqual(pre.textContent, 'hello');
    });
    it('correctly renders ANSI characters', function () {
        var dom = new jsdom_1.JSDOM('<!DOCTYPE html><html lang="en"><body><div id="content"></div></body></html>');
        // React complains if we don't do this
        // @ts-ignore
        global.window = dom.window;
        var document = dom.window.document;
        var attachment = messages_1.messages.Attachment.create({
            mediaType: 'text/x.cucumber.log+plain',
            body: '\x1b[30mblack\x1b[37mwhite',
            contentEncoding: messages_1.messages.Attachment.ContentEncoding.IDENTITY,
        });
        var attachmentElement = react_1.default.createElement(Attachment_1.default, { attachment: attachment });
        react_dom_1.default.render(attachmentElement, document.getElementById('content'));
        var span = document.querySelector('#content pre > span');
        assert_1.default.strictEqual(span.innerHTML, '<span style="color:#000">black<span style="color:#AAA">white</span></span>');
    });
});
//# sourceMappingURL=AttachmentTest.js.map